@@ -50,15 +50,18 @@ class PreferencesDialog : public QDialog, private Ui_PreferencesDialog_UI, publi
 		void on_resampleComboBox_currentIndexChanged ( int index );
 		void on_sampleRateComboBox_editTextChanged( const QString& text );
 		void on_midiPortComboBox_activated( int index );
+		void on_midiOutportComboBox_activated( int index );		
 		void on_styleComboBox_activated( int index );
 		void on_useLashCheckbox_clicked();
 		void onMidiDriverComboBoxIndexChanged( int index );
 		void toggleTrackOutsCheckBox(bool toggled);
+		void toggleOscCheckBox(bool toggled);
 		void coloringMethodCombo_currentIndexChanged (int index);
 
 
 	private:
 		bool m_bNeedDriverRestart;
+		QString m_sInitialLanguage;
 
 		void updateDriverInfo();
 };
